Enum fred::interfaces::Resp3Frame
pub enum Resp3Frame {
Show 16 variants
BlobString {
data: Bytes,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
BlobError {
data: Bytes,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
SimpleString {
data: Bytes,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
SimpleError {
data: StrInner<Bytes>,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
Boolean {
data: bool,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
Null,
Number {
data: i64,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
Double {
data: f64,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
BigNumber {
data: Bytes,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
VerbatimString {
data: Bytes,
format: VerbatimStringFormat,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
Array {
data: Vec<BytesFrame>,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
Map {
data: HashMap<BytesFrame, BytesFrame>,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
Set {
data: HashSet<BytesFrame>,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
Push {
data: Vec<BytesFrame>,
attributes: Option<HashMap<BytesFrame, BytesFrame>>,
},
Hello {
version: RespVersion,
auth: Option<(StrInner<Bytes>, StrInner<Bytes>)>,
setname: Option<StrInner<Bytes>>,
},
ChunkedString(Bytes),
}Variants
BlobString
A blob of bytes.
BlobError
A blob representing an error.
SimpleString
A small string.
The internal data type is Bytes in order to support callers that use this interface to parse a MONITOR
stream.
SimpleError
A small string representing an error.
Boolean
A boolean type.
Null
A null type.
Number
A signed 64-bit integer.
Double
A signed 64-bit floating point number.
BigNumber
A large number not representable as a Number or Double.
This library does not attempt to parse this.
VerbatimString
A string to be displayed without any escaping or filtering.
Array
An array of frames.
Map
An unordered map of key-value pairs.
According to the spec keys can be any other RESP3 data type. However, it doesn’t make sense to implement Hash
for certain aggregate types. The can_hash function can be used to
detect this.
Set
An unordered collection of other frames with a uniqueness constraint.
Push
Out-of-band data.
Hello
A special frame type used when first connecting to the server to describe the protocol version and optional credentials.
Fields
version: RespVersionChunkedString(Bytes)
One chunk of a streaming blob.
Implementations
impl BytesFrame
impl BytesFrame
pub fn to_owned_frame(&self) -> OwnedFrame
pub fn to_owned_frame(&self) -> OwnedFrame
Copy the frame contents into a new [OwnedFrame].