Trait fred::interfaces::SlowlogInterface

source ·
pub trait SlowlogInterface: ClientLike + Sized {
    // Provided methods
    fn slowlog_get<R>(
        &self,
        count: Option<i64>,
    ) -> impl Future<Output = RedisResult<R>>
       where R: FromRedis { ... }
    fn slowlog_length<R>(&self) -> impl Future<Output = RedisResult<R>>
       where R: FromRedis { ... }
    fn slowlog_reset(&self) -> impl Future<Output = RedisResult<()>> { ... }
}
Available on crate feature i-slowlog only.
Functions that implement the slowlog interface.

Provided Methods

source

fn slowlog_get<R>( &self, count: Option<i64>, ) -> impl Future<Output = RedisResult<R>>
where R: FromRedis,

This command is used to read the slow queries log.

https://redis.io/commands/slowlog#reading-the-slow-log

source

fn slowlog_length<R>(&self) -> impl Future<Output = RedisResult<R>>
where R: FromRedis,

This command is used to read length of the slow queries log.

https://redis.io/commands/slowlog#obtaining-the-current-length-of-the-slow-log

source

fn slowlog_reset(&self) -> impl Future<Output = RedisResult<()>>

This command is used to reset the slow queries log.

https://redis.io/commands/slowlog#resetting-the-slow-log

Object Safety

This trait is not object safe.

Implementors