Trait fred::interfaces::AclInterface
source · pub trait AclInterface: ClientLike + Sized {
// Provided methods
fn acl_setuser<S, V>(
&self,
username: S,
rules: V,
) -> impl Future<Output = RedisResult<()>>
where S: Into<Str>,
V: TryInto<MultipleValues>,
V::Error: Into<RedisError> { ... }
fn acl_load(&self) -> impl Future<Output = RedisResult<()>> { ... }
fn acl_save(&self) -> impl Future<Output = RedisResult<()>> { ... }
fn acl_list<R>(&self) -> impl Future<Output = RedisResult<R>>
where R: FromRedis { ... }
fn acl_users<R>(&self) -> impl Future<Output = RedisResult<R>>
where R: FromRedis { ... }
fn acl_getuser<R, S>(
&self,
username: S,
) -> impl Future<Output = RedisResult<R>>
where R: FromRedis,
S: Into<Str> { ... }
fn acl_deluser<R, S>(
&self,
usernames: S,
) -> impl Future<Output = RedisResult<R>>
where R: FromRedis,
S: Into<MultipleStrings> { ... }
fn acl_cat<R>(
&self,
category: Option<Str>,
) -> impl Future<Output = RedisResult<R>>
where R: FromRedis { ... }
fn acl_genpass<R>(
&self,
bits: Option<u16>,
) -> impl Future<Output = RedisResult<R>>
where R: FromRedis { ... }
fn acl_whoami<R>(&self) -> impl Future<Output = RedisResult<R>>
where R: FromRedis { ... }
fn acl_log_count<R>(
&self,
count: Option<u32>,
) -> impl Future<Output = RedisResult<R>>
where R: FromRedis { ... }
fn acl_log_reset(&self) -> impl Future<Output = RedisResult<()>> { ... }
}i-acl only.Expand description
Functions that implement the ACL interface.
Provided Methods
sourcefn acl_setuser<S, V>(
&self,
username: S,
rules: V,
) -> impl Future<Output = RedisResult<()>>
fn acl_setuser<S, V>( &self, username: S, rules: V, ) -> impl Future<Output = RedisResult<()>>
Create an ACL user with the specified rules or modify the rules of an existing user.
sourcefn acl_load(&self) -> impl Future<Output = RedisResult<()>>
fn acl_load(&self) -> impl Future<Output = RedisResult<()>>
When Redis is configured to use an ACL file (with the aclfile configuration option), this command will reload the ACLs from the file, replacing all the current ACL rules with the ones defined in the file.
sourcefn acl_save(&self) -> impl Future<Output = RedisResult<()>>
fn acl_save(&self) -> impl Future<Output = RedisResult<()>>
When Redis is configured to use an ACL file (with the aclfile configuration option), this command will save the currently defined ACLs from the server memory to the ACL file.
sourcefn acl_list<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
fn acl_list<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
The command shows the currently active ACL rules in the Redis server.
sourcefn acl_users<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
fn acl_users<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
The command shows a list of all the usernames of the currently configured users in the Redis ACL system.
sourcefn acl_getuser<R, S>(&self, username: S) -> impl Future<Output = RedisResult<R>>
fn acl_getuser<R, S>(&self, username: S) -> impl Future<Output = RedisResult<R>>
The command returns all the rules defined for an existing ACL user.
sourcefn acl_deluser<R, S>(
&self,
usernames: S,
) -> impl Future<Output = RedisResult<R>>
fn acl_deluser<R, S>( &self, usernames: S, ) -> impl Future<Output = RedisResult<R>>
Delete all the specified ACL users and terminate all the connections that are authenticated with such users.
sourcefn acl_cat<R>(
&self,
category: Option<Str>,
) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
fn acl_cat<R>(
&self,
category: Option<Str>,
) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
The command shows the available ACL categories if called without arguments. If a category name is given, the command shows all the Redis commands in the specified category.
sourcefn acl_genpass<R>(
&self,
bits: Option<u16>,
) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
fn acl_genpass<R>(
&self,
bits: Option<u16>,
) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
Generate a password with length bits, returning the password.
sourcefn acl_whoami<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
fn acl_whoami<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
Return the username the current connection is authenticated with. New connections are authenticated with the “default” user.
sourcefn acl_log_count<R>(
&self,
count: Option<u32>,
) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
fn acl_log_count<R>(
&self,
count: Option<u32>,
) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
Read count recent ACL security events.
sourcefn acl_log_reset(&self) -> impl Future<Output = RedisResult<()>>
fn acl_log_reset(&self) -> impl Future<Output = RedisResult<()>>
Clear the ACL security events logs.