Trait fred::interfaces::MemoryInterface
source · pub trait MemoryInterface: ClientLike + Sized {
// Provided methods
fn memory_doctor<R>(&self) -> impl Future<Output = RedisResult<R>>
where R: FromRedis { ... }
fn memory_malloc_stats<R>(&self) -> impl Future<Output = RedisResult<R>>
where R: FromRedis { ... }
fn memory_purge(&self) -> impl Future<Output = RedisResult<()>> { ... }
fn memory_stats<R>(&self) -> impl Future<Output = RedisResult<R>>
where R: FromRedis { ... }
fn memory_usage<R, K>(
&self,
key: K,
samples: Option<u32>,
) -> impl Future<Output = RedisResult<R>>
where R: FromRedis,
K: Into<RedisKey> { ... }
}Available on crate feature
i-memory only.Expand description
Functions that implement the memory interface.
Provided Methods
sourcefn memory_doctor<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
fn memory_doctor<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
The MEMORY DOCTOR command reports about different memory-related issues that the Redis server experiences, and advises about possible remedies.
sourcefn memory_malloc_stats<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
fn memory_malloc_stats<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
The MEMORY MALLOC-STATS command provides an internal statistics report from the memory allocator.
sourcefn memory_purge(&self) -> impl Future<Output = RedisResult<()>>
fn memory_purge(&self) -> impl Future<Output = RedisResult<()>>
The MEMORY PURGE command attempts to purge dirty pages so these can be reclaimed by the allocator.
sourcefn memory_stats<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
fn memory_stats<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
The MEMORY STATS command returns an Array reply about the memory usage of the server.
sourcefn memory_usage<R, K>(
&self,
key: K,
samples: Option<u32>,
) -> impl Future<Output = RedisResult<R>>
fn memory_usage<R, K>( &self, key: K, samples: Option<u32>, ) -> impl Future<Output = RedisResult<R>>
The MEMORY USAGE command reports the number of bytes that a key and its value require to be stored in RAM.
Object Safety
This trait is not object safe.