Trait fred::interfaces::SlowlogInterface
source · pub trait SlowlogInterface: ClientLike + Sized {
// Provided methods
fn slowlog_get<R>(
&self,
count: Option<i64>,
) -> impl Future<Output = RedisResult<R>>
where R: FromRedis { ... }
fn slowlog_length<R>(&self) -> impl Future<Output = RedisResult<R>>
where R: FromRedis { ... }
fn slowlog_reset(&self) -> impl Future<Output = RedisResult<()>> { ... }
}Available on crate feature
i-slowlog only.Expand description
Functions that implement the slowlog interface.
Provided Methods
sourcefn slowlog_get<R>(
&self,
count: Option<i64>,
) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
fn slowlog_get<R>(
&self,
count: Option<i64>,
) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
This command is used to read the slow queries log.
sourcefn slowlog_length<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
fn slowlog_length<R>(&self) -> impl Future<Output = RedisResult<R>>where
R: FromRedis,
This command is used to read length of the slow queries log.
https://redis.io/commands/slowlog#obtaining-the-current-length-of-the-slow-log
sourcefn slowlog_reset(&self) -> impl Future<Output = RedisResult<()>>
fn slowlog_reset(&self) -> impl Future<Output = RedisResult<()>>
This command is used to reset the slow queries log.
Object Safety
This trait is not object safe.